@@ -4,8 +4,9 @@
 # sens/spec
 #' Sample size and precision of sensitivity and specificity
 #'
-#' Because sensitivity and specificity are simple proportions, these functions
-#' act as wrappers for \code{prec_prop}.
+#' Because sensitivity (true positives/total number of positives) and specificity (true
+#' negatives/total number of negatives) are simple proportions, these
+#' functions act as wrappers for \code{prec_prop}.
 #'
 #' If \code{ntot} and \code{prev} are given, they are used to calculate
 #'   \code{n}.
@@ -39,7 +40,7 @@ prec_sens <- function(sens, n = NULL, ntot = NULL, prev = NULL,
                       conf.width = NULL, round = "ceiling", ...){
   if (!is.null(n) & !is.null(ntot)) stop("supply 'n' or 'ntot' and 'prev'")
   if (!is.null(ntot) & is.null(prev)) stop("'prev' required when 'ntot' is specified")
-  if (is.null(ntot) & !is.null(prev)) stop("'ntot' required when 'prev' is specified")
+  if (is.null(conf.width)) if(is.null(ntot) & !is.null(prev)) stop("'ntot' required when 'prev' is specified")
   # if (!round %in% c("ceiling", "floor")) stop("choices for 'round' are 'ceiling' or 'floor'")
 
   if (!is.null(sens)) numrange_check(sens)
@@ -65,7 +66,7 @@ prec_sens <- function(sens, n = NULL, ntot = NULL, prev = NULL,
 
   pp <- prec_prop(sens, n, conf.width, ...)
 
-  if (!is.null(prev) & is.na(ntot)) {
+  if (any(!is.null(prev) & is.na(ntot))) {
     ntot <- pp$n * (1 / prev)
   }
 
@@ -91,7 +92,7 @@ prec_spec <- function(spec, n = NULL, ntot = NULL, prev = NULL, conf.width = NUL
   if (!is.null(n) & !is.null(ntot)) stop("supply 'n' or 'ntot' and 'prev'")
   # if (!round %in% c("ceiling", "floor")) stop("choices for 'round' are 'ceiling' or 'floor'")
   if (!is.null(ntot) & is.null(prev)) stop("'prev' required when 'ntot' is specified")
-  if (is.null(ntot) & !is.null(prev)) stop("'ntot' required when 'prev' is specified")
+  if (is.null(conf.width)) if(is.null(ntot) & !is.null(prev)) stop("'ntot' required when 'prev' is specified")
 
   if (!is.null(spec)) numrange_check(spec)
   if (!is.null(n)) numrange_check_gt(n)
@@ -116,7 +117,7 @@ prec_spec <- function(spec, n = NULL, ntot = NULL, prev = NULL, conf.width = NUL
 
   pp <- prec_prop(spec, n, conf.width, ...)
 
-  if (!is.null(prev) & is.na(ntot)) {
+  if (any(!is.null(prev) & is.na(ntot))) {
     ntot <- pp$n * (1 / (1 - prev))
   }
 
